@@ -47,6 +47,7 @@ pub enum NetworkError {
     StorageError(StorageError),
     SyncIntervalInvalid,
     ZeroLengthMessage,
+    Other(anyhow::Error),
 }
 
 impl NetworkError {
@@ -142,3 +143,9 @@ impl From<NetworkError> for anyhow::Error {
         Self::msg(error.to_string())
     }
 }
+
+impl From<anyhow::Error> for NetworkError {
+    fn from(other: anyhow::Error) -> Self {
+        Self::Other(other)
+    }
+}
