@@ -17,15 +17,11 @@
 use anyhow::*;
 use chrono::Utc;
 use serde::{Deserialize, Serialize};
+use snarkos_metrics::wrapped_mpsc;
 use std::{
     net::SocketAddr,
-    sync::{
-        atomic::{AtomicUsize, Ordering},
-        Arc,
-    },
     time::{Duration, Instant},
 };
-use tokio::sync::mpsc;
 
 use super::PeerQuality;
 use crate::{message::Payload, BlockCache, NetworkError, Node};
@@ -36,11 +32,6 @@ use super::{network::*, outbound_handler::*};
 pub struct Peer {
     pub address: SocketAddr,
     pub quality: PeerQuality,
-    pub is_bootnode: bool,
-    #[serde(skip)]
-    pub queued_inbound_message_count: Arc<AtomicUsize>,
-    #[serde(skip)]
-    pub queued_outbound_message_count: Arc<AtomicUsize>,
     /// Whether this peer is routable or not.
     ///
     /// `None` indicates the node has never attempted a connection with this peer.
@@ -54,13 +45,10 @@ const FAILURE_EXPIRY_TIME: Duration = Duration::from_secs(15 * 60);
 const FAILURE_THRESHOLD: usize = 5;
 
 impl Peer {
-    pub fn new(address: SocketAddr, is_bootnode: bool) -> Self {
+    pub fn new(address: SocketAddr) -> Self {
         Self {
             address,
             quality: Default::default(),
-            is_bootnode,
-            queued_inbound_message_count: Default::default(),
-            queued_outbound_message_count: Default::default(),
 
             // Set to `None` since peer creation only ever happens before a connection to the peer,
             // therefore we don't know if its listener is routable or not.
@@ -97,28 +85,16 @@ impl Peer {
         self.quality.failures.len()
     }
 
-    pub fn handshake_timeout(&self) -> Duration {
-        if self.is_bootnode {
-            Duration::from_secs(crate::HANDSHAKE_BOOTNODE_TIMEOUT_SECS as u64)
-        } else {
-            Self::peer_handshake_timeout()
-        }
-    }
-
-    pub fn peer_handshake_timeout() -> Duration {
-        Duration::from_secs(crate::HANDSHAKE_PEER_TIMEOUT_SECS as u64)
-    }
-
     pub(super) async fn run(
         &mut self,
         node: Node,
         mut network: PeerIOHandle,
-        mut receiver: mpsc::Receiver<PeerAction>,
+        mut receiver: wrapped_mpsc::Receiver<PeerAction>,
     ) -> Result<(), NetworkError> {
         let mut reader = network.take_reader();
 
-        let (sender, mut read_receiver) = mpsc::channel::<Result<Vec<u8>, NetworkError>>(8);
-        let queued_inbound_message_count = self.queued_inbound_message_count.clone();
+        let (sender, mut read_receiver) =
+            wrapped_mpsc::channel::<Result<Vec<u8>, NetworkError>>(snarkos_metrics::queues::INBOUND, 8);
 
         tokio::spawn(async move {
             loop {
@@ -128,9 +104,6 @@ impl Peer {
                     .is_err()
                 {
                     break;
-                } else {
-                    queued_inbound_message_count.fetch_add(1, Ordering::SeqCst);
-                    metrics::increment_gauge!(snarkos_metrics::queues::INBOUND, 1.0);
                 }
             }
         });
@@ -154,9 +127,6 @@ impl Peer {
                         break;
                     }
 
-                    self.queued_inbound_message_count.fetch_sub(1, Ordering::SeqCst);
-                    metrics::decrement_gauge!(snarkos_metrics::queues::INBOUND, 1.0);
-
                     let data = match data.unwrap() {
                         // decrypt
                         Ok(data) => network.read_payload(&data[..]),
@@ -178,11 +148,6 @@ impl Peer {
             }
         }
 
-        let queued_inbound_message_count = self.queued_inbound_message_count.swap(0, Ordering::SeqCst);
-        metrics::decrement_gauge!(snarkos_metrics::queues::INBOUND, queued_inbound_message_count as f64);
-        let queued_outbound_message_count = self.queued_outbound_message_count.swap(0, Ordering::SeqCst);
-        metrics::decrement_gauge!(snarkos_metrics::queues::OUTBOUND, queued_outbound_message_count as f64);
-
         Ok(())
     }
 
